.. _users-guide-index:

============
 User Guide
============

:Release: |version|
:Date: |today|

.. toctree::
   :maxdepth: 2

   install
   neurodocker
   caching_tutorial

.. toctree::
   Nipype tutorials <https://miykael.github.io/nipype_tutorial/>
   Porcupine graphical interface <https://timvanmourik.github.io/Porcupine/getting-started/>

.. toctree::
   :maxdepth: 1

   plugins
   config_file
   debug
   cli

.. toctree::
   :maxdepth: 1

   grabbing_and_sinking
   select_files
   function_interface
   mapnode_and_iterables
   joinnode_and_itersource
   model_specification
   saving_workflows
   spmmcr
   mipav
   nipypecmd
   aws
   resource_sched_profiler
   sphinx_ext





